<?php

namespace Codi22\VLAN\Policies;

use App\User;
use Codi22\VLAN\Models\VLANS;

class VLANSPolicy
{

    /**
     * Determine if the given user can view the v_l_a_n_s.
     *
     * @param User $user
     * @param VLANS $v_l_a_n_s
     *
     * @return bool
     */
    public function view(User $user, VLANS $v_l_a_n_s)
    {
        if ($user->canDo('v_l_a_n.v_l_a_n_s.view') && $user->is('admin')) {
            return true;
        }

        if ($user->canDo('blocks.block.view') 
        && $user->is('manager')
        && $block->user->parent_id == $user->id) {
            return true;
        }

        return $user->id === $v_l_a_n_s->user_id;
    }

    /**
     * Determine if the given user can create a v_l_a_n_s.
     *
     * @param User $user
     * @param VLANS $v_l_a_n_s
     *
     * @return bool
     */
    public function create(User $user)
    {
        return  $user->canDo('v_l_a_n.v_l_a_n_s.create');
    }

    /**
     * Determine if the given user can update the given v_l_a_n_s.
     *
     * @param User $user
     * @param VLANS $v_l_a_n_s
     *
     * @return bool
     */
    public function update(User $user, VLANS $v_l_a_n_s)
    {
        if ($user->canDo('v_l_a_n.v_l_a_n_s.update') && $user->is('admin')) {
            return true;
        }

        if ($user->canDo('blocks.block.update') 
        && $user->is('manager')
        && $block->user->parent_id == $user->id) {
            return true;
        }

        return $user->id === $v_l_a_n_s->user_id;
    }

    /**
     * Determine if the given user can delete the given v_l_a_n_s.
     *
     * @param User $user
     * @param VLANS $v_l_a_n_s
     *
     * @return bool
     */
    public function destroy(User $user, VLANS $v_l_a_n_s)
    {
        if ($user->canDo('v_l_a_n.v_l_a_n_s.delete') && $user->is('admin')) {
            return true;
        }

        if ($user->canDo('blocks.block.delete') 
        && $user->is('manager')
        && $block->user->parent_id == $user->id) {
            return true;
        }

        return $user->id === $v_l_a_n_s->user_id;
    }

    /**
     * Determine if the given user can verify the given v_l_a_n_s.
     *
     * @param User $user
     * @param VLANS $v_l_a_n_s
     *
     * @return bool
     */
    public function verify(User $user, VLANS $v_l_a_n_s)
    {
        if ($user->canDo('v_l_a_n.v_l_a_n_s.verify') && $user->is('admin')) {
            return true;
        }

        if ($user->canDo('v_l_a_n.v_l_a_n_s.verify') 
        && $user->is('manager')
        && $v_l_a_n_s->user->parent_id == $user->id) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given v_l_a_n_s.
     *
     * @param User $user
     * @param VLANS $v_l_a_n_s
     *
     * @return bool
     */
    public function approve(User $user, VLANS $v_l_a_n_s)
    {
        if ($user->canDo('v_l_a_n.v_l_a_n_s.approve') && $user->is('admin')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperUser()) {
            return true;
        }
    }
}
