<?php

namespace Codi22\VLAN\Providers;

use Illuminate\Support\ServiceProvider;

class VLANServiceProvider extends ServiceProvider
{
    /**
     * Indicates if loading of the provider is deferred.
     *
     * @var bool
     */
    protected $defer = false;

    /**
     * Bootstrap the application events.
     *
     * @return void
     */
    public function boot()
    {
        // Load view
        $this->loadViewsFrom(__DIR__ . '/../../../../resources/views', 'v_l_a_n');

        // Load translation
        $this->loadTranslationsFrom(__DIR__ . '/../../../../resources/lang', 'v_l_a_n');

        // Call pblish redources function
        $this->publishResources();

    }

    /**
     * Register the service provider.
     *
     * @return void
     */
    public function register()
    {
        // Bind facade
        $this->app->bind('v_l_a_n', function ($app) {
            return $this->app->make('Codi22\VLAN\VLAN');
        });

        // Bind VLANS to repository
        $this->app->bind(
            \Codi22\VLAN\Interfaces\VLANSRepositoryInterface::class,
            \Codi22\VLAN\Repositories\Eloquent\VLANSRepository::class
        );

        $this->app->register(\Codi22\VLAN\Providers\AuthServiceProvider::class);
        $this->app->register(\Codi22\VLAN\Providers\EventServiceProvider::class);
        $this->app->register(\Codi22\VLAN\Providers\RouteServiceProvider::class);
        // $this->app->register(\Codi22\VLAN\Providers\WorkflowServiceProvider::class);
    }

    /**
     * Get the services provided by the provider.
     *
     * @return array
     */
    public function provides()
    {
        return ['v_l_a_n'];
    }

    /**
     * Publish resources.
     *
     * @return void
     */
    private function publishResources()
    {
        // Publish configuration file
        $this->publishes([__DIR__ . '/../../../../config/config.php' => config_path('codi22/v_l_a_n.php')], 'config');

        // Publish admin view
        $this->publishes([__DIR__ . '/../../../../resources/views' => base_path('resources/views/vendor/v_l_a_n')], 'view');

        // Publish language files
        $this->publishes([__DIR__ . '/../../../../resources/lang' => base_path('resources/lang/vendor/v_l_a_n')], 'lang');

        // Publish migrations
        $this->publishes([__DIR__ . '/../../../../database/migrations/' => base_path('database/migrations')], 'migrations');

        // Publish seeds
        $this->publishes([__DIR__ . '/../../../../database/seeds/' => base_path('database/seeds')], 'seeds');

        // Publish public files and assets.
        $this->publishes([__DIR__ . '/public/' => public_path('/')], 'public');
    }
}
