<?php

namespace Codi22\VLAN\Workflow;

use Codi22\VLAN\Models\VLANS;
use Validator;

class VLANSValidator
{

    /**
     * Determine if the given v_l_a_n_s is valid for complete status.
     *
     * @param VLANS $v_l_a_n_s
     *
     * @return bool / Validator
     */
    public function complete(VLANS $v_l_a_n_s)
    {
        return Validator::make($v_l_a_n_s->toArray(), [
            'title' => 'required|min:15',
        ]);
    }

    /**
     * Determine if the given v_l_a_n_s is valid for verify status.
     *
     * @param VLANS $v_l_a_n_s
     *
     * @return bool / Validator
     */
    public function verify(VLANS $v_l_a_n_s)
    {
        return Validator::make($v_l_a_n_s->toArray(), [
            'title'  => 'required|min:15',
            'status' => 'in:complete',
        ]);
    }

    /**
     * Determine if the given v_l_a_n_s is valid for approve status.
     *
     * @param VLANS $v_l_a_n_s
     *
     * @return bool / Validator
     */
    public function approve(VLANS $v_l_a_n_s)
    {
        return Validator::make($v_l_a_n_s->toArray(), [
            'title'  => 'required|min:15',
            'status' => 'in:verify',
        ]);

    }

    /**
     * Determine if the given v_l_a_n_s is valid for publish status.
     *
     * @param VLANS $v_l_a_n_s
     *
     * @return bool / Validator
     */
    public function publish(VLANS $v_l_a_n_s)
    {
        return Validator::make($v_l_a_n_s->toArray(), [
            'title'       => 'required|min:15',
            'description' => 'required|min:50',
            'status'      => 'in:approve,archive,unpublish',
        ]);

    }

    /**
     * Determine if the given v_l_a_n_s is valid for archive status.
     *
     * @param VLANS $v_l_a_n_s
     *
     * @return bool / Validator
     */
    public function archive(VLANS $v_l_a_n_s)
    {
        return Validator::make($v_l_a_n_s->toArray(), [
            'title'       => 'required|min:15',
            'description' => 'required|min:50',
            'status'      => 'in:approve,publish,unpublish',
        ]);

    }

    /**
     * Determine if the given v_l_a_n_s is valid for unpublish status.
     *
     * @param VLANS $v_l_a_n_s
     *
     * @return bool / Validator
     */
    public function unpublish(VLANS $v_l_a_n_s)
    {
        return Validator::make($v_l_a_n_s->toArray(), [
            'title'       => 'required|min:15',
            'description' => 'required|min:50',
            'status'      => 'in:publish',
        ]);

    }
}
